"use strict";Object.defineProperty(exports, "__esModule", {value: true});// src/common/time.ts
function getTimestamp() {
  return Date.now();
}
function getTimestampInSeconds() {
  return Math.floor(Date.now() / 1e3);
}
function dateFromSeconds(ts) {
  return new Date(ts * 1e3);
}
function formatMilliseconds(ms) {
  return ms > 999 ? `${(ms / 1e3).toFixed(1)} s` : `${ms.toFixed(2)} ms`;
}
function parseDate(...dateCandidates) {
  for (const dateCandidate of dateCandidates) {
    if (dateCandidate instanceof Date)
      return dateCandidate;
    if (typeof dateCandidate === "string") {
      let date = null;
      if (dateCandidate.includes(":")) {
        try {
          date = new Date(dateCandidate);
        } catch (err) {
        }
      }
      if (!(date instanceof Date)) {
        const m = /(\d\d\d\d)-(\d\d)-(\d\d)/.exec(dateCandidate);
        if (m)
          date = new Date(+m[1], +m[2] - 1, +m[3], 12, 0);
      }
      if (date instanceof Date)
        return date;
    }
  }
}
function getPerformanceTimestamp() {
  return typeof performance !== "undefined" ? performance.now() : Date.now();
}
function duration() {
  const t0 = getPerformanceTimestamp();
  return function() {
    const duration2 = getPerformanceTimestamp() - t0;
    return formatMilliseconds(duration2);
  };
}
function datetimeToLocal(fromDate) {
  return new Date(
    fromDate.getUTCFullYear(),
    fromDate.getUTCMonth(),
    fromDate.getUTCDate(),
    fromDate.getUTCHours(),
    fromDate.getUTCMinutes(),
    fromDate.getUTCSeconds(),
    fromDate.getUTCMilliseconds()
  );
}
function datetimeToUTC(fromDate) {
  return new Date(Date.UTC(
    fromDate.getFullYear(),
    fromDate.getMonth(),
    fromDate.getDate(),
    fromDate.getHours(),
    fromDate.getMinutes(),
    fromDate.getSeconds(),
    fromDate.getMilliseconds()
  ));
}
function timestampMillisecondsToSeconds(ts) {
  if (ts <= 0)
    return 0;
  if (ts < 1e12) {
    return ts;
  }
  return Math.floor(ts / 1e3);
}
function timestampSecondsToMilliseconds(ts) {
  if (ts <= 0)
    return 0;
  if (ts > 1e12) {
    return ts;
  }
  return Math.floor(ts * 1e3);
}
var TIME_YEAR_MS = 31536e6;
var TIME_YEAR_S = 31536e3;
var TIME_MONTH_MS = 2592e6;
var TIME_MONTH_S = 2592e3;
var TIME_WEEK_MS = 6048e5;
var TIME_WEEK_S = 604800;
var TIME_DAY_MS = 864e5;
var TIME_DAY_S = 86400;
var TIME_HOUR_MS = 36e5;
var TIME_HOUR_S = 3600;
var TIME_MINUTE_MS = 6e4;
var TIME_MINUTE_S = 60;

























exports.getTimestamp = getTimestamp; exports.getTimestampInSeconds = getTimestampInSeconds; exports.dateFromSeconds = dateFromSeconds; exports.formatMilliseconds = formatMilliseconds; exports.parseDate = parseDate; exports.getPerformanceTimestamp = getPerformanceTimestamp; exports.duration = duration; exports.datetimeToLocal = datetimeToLocal; exports.datetimeToUTC = datetimeToUTC; exports.timestampMillisecondsToSeconds = timestampMillisecondsToSeconds; exports.timestampSecondsToMilliseconds = timestampSecondsToMilliseconds; exports.TIME_YEAR_MS = TIME_YEAR_MS; exports.TIME_YEAR_S = TIME_YEAR_S; exports.TIME_MONTH_MS = TIME_MONTH_MS; exports.TIME_MONTH_S = TIME_MONTH_S; exports.TIME_WEEK_MS = TIME_WEEK_MS; exports.TIME_WEEK_S = TIME_WEEK_S; exports.TIME_DAY_MS = TIME_DAY_MS; exports.TIME_DAY_S = TIME_DAY_S; exports.TIME_HOUR_MS = TIME_HOUR_MS; exports.TIME_HOUR_S = TIME_HOUR_S; exports.TIME_MINUTE_MS = TIME_MINUTE_MS; exports.TIME_MINUTE_S = TIME_MINUTE_S;
//# sourceMappingURL=chunk-33B2TEAZ.cjs.map