import {
  objectPlain
} from "./chunk-PIP5E7GF.js";
import {
  Uint8ArrayToHexDump
} from "./chunk-4LNR3HBM.js";
import {
  isArray
} from "./chunk-MSASB4XB.js";

// src/common/data/message.ts
function formatMessages(messages, opt = {}) {
  const { trace = true, pretty = true } = opt;
  return messages.map((obj) => {
    if (obj && typeof obj === "object") {
      if (pretty && (obj instanceof Uint8Array || obj instanceof ArrayBuffer))
        return `
${Uint8ArrayToHexDump(obj)}
`;
      if (obj instanceof Error) {
        return `${obj.name}: ${obj.message}` + (trace ? `
${obj.stack}` : "");
      }
      if (typeof ErrorEvent !== "undefined" && obj instanceof ErrorEvent) {
        return `${obj.error.name || "ErrorEvent"}: ${obj.error.message}` + (trace ? `
${obj.error.stack}` : "");
      }
      if (typeof DOMException !== "undefined" && obj instanceof DOMException) {
        return `${obj.name || "DOMException"}: ${obj.message}` + (trace ? `
${obj.stack}` : "");
      }
      if (obj && typeof obj === "object" && "reason" in obj) {
        return `PromiseRejection ${obj.type}: ${obj.reason}` + (trace ? `
${obj.stack}` : "");
      }
      try {
        obj = objectPlain(obj);
        return pretty ? JSON.stringify(obj, null, 2) : JSON.stringify(obj);
      } catch (err) {
      }
    }
    return String(obj);
  });
}
function renderMessages(messages, opt = {}) {
  return formatMessages(isArray(messages) ? messages : [messages], opt).join(" ");
}

export {
  formatMessages,
  renderMessages
};
//# sourceMappingURL=chunk-CXMKDBGU.js.map