import {
  isSchemaObjectFlat
} from "./chunk-HIX6EHLQ.js";
import {
  valueToInteger
} from "./chunk-KKN5DQUJ.js";
import {
  fromCamelCase,
  toCamelCase
} from "./chunk-XOAKJFNZ.js";
import {
  objectMap
} from "./chunk-PIP5E7GF.js";
import {
  assert
} from "./chunk-GAB5OQ4U.js";

// src/common/schema/args.ts
function parseSchemaArgs(schema, args = process?.argv ?? {}) {
  assert(isSchemaObjectFlat(schema), "schema should be a flat object");
  const alias = {};
  const booleanArgs = [];
  objectMap(schema._object, (key, schema2) => {
    if (schema2._props?.argShort)
      alias[toCamelCase(schema2._props.argShort)] = toCamelCase(key);
    if (schema2.type === "boolean") {
      booleanArgs.push(toCamelCase(key));
    }
  });
  const argList = [...args];
  let arg;
  const names = [];
  const argsObj = {};
  while (arg = argList.shift()) {
    let value;
    if (/^--?/.test(arg)) {
      let key = arg.replace(/^--?/, "");
      if (arg.includes("=")) {
        const [name, valuePart] = key.split("=", 2);
        key = name.trim();
        value = valuePart.trim();
      }
      key = toCamelCase(key);
      key = alias[key] ?? key;
      if (booleanArgs.includes(key)) {
        argsObj[key] = true;
      } else {
        value = value ?? argList.shift() ?? "";
        argsObj[key] = value;
      }
    } else {
      names.push(arg);
    }
  }
  const argsResult = objectMap(schema._object, (key, schema2) => {
    let value = argsObj[toCamelCase(key)];
    if (schema2.type === "number") {
      value = valueToInteger(value);
    }
    return schema2.parse(value);
  });
  return [argsResult, names];
}
function helpSchemaArgs(schema) {
  assert(isSchemaObjectFlat(schema), "schema should be a flat object");
  const lines = [];
  objectMap(schema._object, (key, schema2) => {
    let s = `--${fromCamelCase(key)}`;
    if (schema2._props?.argShort)
      s += `, -${fromCamelCase(schema2._props.argShort)}`;
    if (schema2.type !== "boolean")
      s += `=${schema2.type}`;
    lines.push(s);
    if (schema2._props?.argDesc)
      lines.push(`  ${schema2._props?.argDesc}`);
  });
  return lines.join("\n");
}

export {
  parseSchemaArgs,
  helpSchemaArgs
};
//# sourceMappingURL=chunk-I2VL3EYP.js.map