"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _nullishCoalesce(lhs, rhsFn) { if (lhs != null) { return lhs; } else { return rhsFn(); } } function _optionalChain(ops) { let lastAccessLHS = undefined; let value = ops[0]; let i = 1; while (i < ops.length) { const op = ops[i]; const fn = ops[i + 1]; i += 2; if ((op === 'optionalAccess' || op === 'optionalCall') && value == null) { return undefined; } if (op === 'access' || op === 'optionalAccess') { lastAccessLHS = value; value = fn(value); } else if (op === 'call' || op === 'optionalCall') { value = fn((...args) => value.call(lastAccessLHS, ...args)); lastAccessLHS = undefined; } } return value; }

var _chunk334CCXIKcjs = require('./chunk-334CCXIK.cjs');


var _chunkMTWPH7QTcjs = require('./chunk-MTWPH7QT.cjs');



var _chunkTF6RVG6Ccjs = require('./chunk-TF6RVG6C.cjs');


var _chunk5TCFLJWDcjs = require('./chunk-5TCFLJWD.cjs');


var _chunkN5KTMDVOcjs = require('./chunk-N5KTMDVO.cjs');

// src/common/exec/pool.ts
function usePool(config = {}) {
  const {
    maxParallel = 3,
    name = _chunkTF6RVG6Ccjs.uname.call(void 0, "pool"),
    idConflictResolution = "memoize"
  } = config;
  const events = new (0, _chunkMTWPH7QTcjs.Emitter)();
  const dispose = _chunk5TCFLJWDcjs.useDispose.call(void 0, );
  dispose.add(cancelAll);
  const progress = new (0, _chunk334CCXIKcjs.Progress)({ name });
  progress.on("progressCancelled", cancelAll);
  let countMax = 0;
  let countResolved = 0;
  let currentParallel = 0;
  let priority = 0;
  const tasks = {};
  async function waitFinishAll() {
    if (countMax > 0) {
      const [promise, resolve] = _chunkN5KTMDVOcjs.createPromise.call(void 0, );
      events.once("didFinish", resolve);
      return promise;
    }
  }
  async function cleanupFinished() {
    for (const id of Object.keys(tasks)) {
      const task = tasks[id];
      if (task.state === "finished") {
        await tasks[id].progress.dispose();
        delete tasks[id];
      }
    }
  }
  function didFinish() {
    void events.emit("didFinish");
    countMax = 0;
    countResolved = 0;
    void cleanupFinished();
    progress.reset();
  }
  function didUpdate() {
    let presentMax = 0;
    let presentResolved = 0;
    for (const { max, resolved, state } of Object.values(tasks)) {
      presentMax += max;
      presentResolved += state === "finished" ? max : Math.min(max, resolved);
    }
    void events.emit(
      "didUpdate",
      countMax,
      countResolved,
      presentMax,
      presentResolved
    );
  }
  function performNext() {
    didUpdate();
    if (countMax > 0 && countMax === countResolved)
      didFinish();
    if (currentParallel >= maxParallel)
      return;
    const waitingTasks = Object.values(tasks).filter(
      (t) => t.state === "waiting"
    );
    if (waitingTasks.length > 0) {
      let taskInfo;
      for (const t of waitingTasks) {
        if (t.group != null && Object.values(tasks).some(
          (tt) => tt.state === "running" && tt.id !== t.id && tt.group === t.group
        )) {
          continue;
        }
        if (taskInfo == null || t.priority < taskInfo.priority)
          taskInfo = t;
      }
      if (taskInfo != null) {
        const id = taskInfo.id;
        const done = taskInfo.done;
        taskInfo.state = "running";
        ++currentParallel;
        void events.emit("didStart", id);
        const taskFinished = (result) => {
          if (taskInfo) {
            taskInfo.result = result;
            taskInfo.state = "finished";
            taskInfo.resolved = taskInfo.max;
            _optionalChain([taskInfo, 'access', _ => _.progress, 'optionalAccess', _2 => _2.setCompleted, 'call', _3 => _3()]);
          }
          --currentParallel;
          ++countResolved;
          performNext();
        };
        taskInfo.task(taskInfo).then((r) => {
          done(r);
          void events.emit("didResolve", id, r);
          taskFinished(r);
        }).catch((err) => {
          done();
          void events.emit("didReject", id, err);
          taskFinished();
        });
      }
    }
  }
  function cancel(id) {
    const taskInfo = tasks[id];
    if (taskInfo && taskInfo.state === "waiting") {
      tasks[id].state = "finished";
      ++countResolved;
      void events.emit("didCancel", id);
      void tasks[id].progress.dispose();
      didUpdate();
    }
  }
  function cancelAll() {
    Object.keys(tasks).forEach(cancel);
  }
  function hasById(id) {
    return tasks[id] != null;
  }
  function enqueue(task, config2 = {}) {
    let done;
    const promise = new Promise((resolve) => done = resolve);
    const id = _nullishCoalesce(config2.id, () => ( _chunkTF6RVG6Ccjs.uuid.call(void 0, )));
    if (tasks[id] != null) {
      const resolution = _nullishCoalesce(config2.idConflictResolution, () => ( idConflictResolution));
      if (resolution === "replace") {
        cancel(id);
      } else if (resolution === "memoize" || resolution === "prioritize") {
        const runningTask = tasks[id];
        if (resolution === "prioritize")
          runningTask.priority = ++priority;
        return {
          id,
          promise: (async () => {
            if (runningTask.state === "finished")
              return tasks[id].result;
          })(),
          dispose: () => cancel(id),
          cancel: () => cancel(id)
        };
      } else {
        throw new Error(`Pool task with id=${id} already exists!`);
      }
    }
    const taskProgress = new (0, _chunk334CCXIKcjs.Progress)({
      name: id,
      totalUnits: _nullishCoalesce(config2.max, () => ( 1)),
      completeUnits: _nullishCoalesce(config2.resolved, () => ( 0))
    });
    progress.addChild(taskProgress);
    tasks[id] = {
      id,
      task,
      priority: ++priority,
      group: config2.group,
      state: "waiting",
      max: _nullishCoalesce(config2.max, () => ( 1)),
      resolved: _nullishCoalesce(config2.resolved, () => ( 0)),
      done,
      payload: config2.payload,
      progress: taskProgress,
      /** @deprecated should use `.progress` */
      setMax(units) {
        taskProgress.setTotalUnits(units);
        tasks[id].max = units;
        didUpdate();
      },
      /** @deprecated should use `.progress` */
      setResolved(units) {
        taskProgress.setCompletetedUnits(units);
        tasks[id].resolved = units;
        didUpdate();
      },
      /** @deprecated should use `.progress` */
      incResolved(inc = 1) {
        taskProgress.incCompletedUnits(inc);
        tasks[id].resolved += inc;
        didUpdate();
      }
    };
    ++countMax;
    performNext();
    return {
      id,
      promise,
      dispose: () => cancel(id),
      cancel: () => cancel(id)
    };
  }
  return {
    events,
    cancel,
    cancelAll,
    hasById,
    progress,
    enqueue,
    dispose,
    waitFinishAll
  };
}



exports.usePool = usePool;
//# sourceMappingURL=chunk-OJKBG3DM.cjs.map