import {
  decodeBase32,
  decodeBase62,
  encodeBase32,
  encodeBase62
} from "./chunk-LRNHXH3A.js";
import {
  randomUint8Array
} from "./chunk-N33MGVUS.js";
import {
  Uint8ArrayToString,
  fromHex,
  toHex,
  toUint8Array
} from "./chunk-4LNR3HBM.js";
import {
  getTimestamp
} from "./chunk-NNCJ3QL5.js";

// src/common/uuid.ts
var uuidBytesLength = 16;
function uuidBytes() {
  return randomUint8Array(uuidBytesLength);
}
function uuidB62(bytes = uuidBytes()) {
  return encodeBase62(bytes, 22);
}
function uuidEncodeB62(bytes) {
  return encodeBase62(bytes, 22);
}
function uuidDecodeB62(uuid2) {
  return decodeBase62(uuid2, uuidBytesLength);
}
function uuidB32(bytes = uuidBytes()) {
  return encodeBase32(bytes, 26);
}
function uuidEncodeB32(bytes) {
  return encodeBase32(bytes, 26);
}
function uuidDecodeB32(uuid2) {
  return decodeBase32(uuid2, uuidBytesLength);
}
var pattern = "10000000-1000-4000-8000-100000000000";
var uuidv4 = function() {
  return typeof crypto !== "undefined" && crypto.randomUUID != null ? crypto.randomUUID() : pattern.replace(/[018]/g, (c) => (c ^ randomUint8Array(1)[0] & 15 >> c / 4).toString(16));
};
function uuidEncodeV4(bytes) {
  const id = toHex(bytes);
  return `${id.slice(0, 8)}-${id.slice(8, 12)}-${id.slice(12, 16)}-${id.slice(16, 20)}-${id.slice(20)}`;
}
function uuidDecodeV4(uuid2) {
  return fromHex(uuid2.replace(/-/g, ""));
}
var ReferenceDateInMS = 16e11;
function longToByteArray(long) {
  const byteArray = new Uint8Array([0, 0, 0, 0, 0, 0]);
  const bytes = byteArray.length - 1;
  for (let index = 0; index < byteArray.length; index++) {
    const byte = long & 255;
    byteArray[bytes - index] = byte;
    long = (long - byte) / 256;
  }
  return byteArray;
}
function suidBytes() {
  const ms = getTimestamp() - ReferenceDateInMS;
  return new Uint8Array([...longToByteArray(ms), ...randomUint8Array(10)]);
}
function suid() {
  return uuidEncode(suidBytes());
}
function suidDate(id) {
  return suidBytesDate(uuidDecode(id));
}
function suidBytesDate(id) {
  return new Date(
    ReferenceDateInMS + id.slice(0, 6).reduce((acc, byte) => acc * 256 + byte, 0)
  );
}
function uuid32bit() {
  return new Uint32Array(randomUint8Array(4))[0];
}
var mapModes = {
  base62: {
    uuid: uuidB62,
    uuidDecode: uuidDecodeB62,
    uuidEncode: uuidEncodeB62
  },
  base32: {
    uuid: uuidB32,
    uuidDecode: uuidDecodeB32,
    uuidEncode: uuidEncodeB32
  },
  uuidv4: {
    uuid: uuidv4,
    uuidDecode: uuidDecodeV4,
    uuidEncode: uuidEncodeV4
  },
  test: {
    uuid: () => uname("test"),
    uuidDecode: (id) => toUint8Array(id),
    uuidEncode: (bin) => Uint8ArrayToString(bin)
  }
};
var _mode = "base62";
var _sorted = false;
function setUuidDefaultEncoding(mode, sorted = false) {
  if (mode === "test")
    unameReset("test");
  _mode = mode ?? "base62";
  _sorted = sorted;
}
function uuid() {
  return mapModes[_mode].uuid(_sorted ? suidBytes() : uuidBytes());
}
function uuidDecode(uuid2) {
  return mapModes[_mode].uuidDecode(uuid2);
}
function uuidEncode(bytes) {
  return mapModes[_mode].uuidEncode(bytes);
}
function uuidIsValid(uuid2) {
  try {
    const bin = uuidDecode(uuid2);
    return bin.length === uuidBytesLength;
  } catch (err) {
  }
  return false;
}
var _unameCounters = {};
function uname(name = "id") {
  if (_unameCounters[name] == null)
    _unameCounters[name] = 0;
  return `${name}-${_unameCounters[name]++}`;
}
function unameReset(name = "id") {
  _unameCounters[name] = 0;
}
var _qid = 0;
function qid() {
  return `id-${_qid++}`;
}

export {
  uuidBytes,
  uuidB62,
  uuidEncodeB62,
  uuidDecodeB62,
  uuidB32,
  uuidEncodeB32,
  uuidDecodeB32,
  uuidv4,
  uuidEncodeV4,
  uuidDecodeV4,
  suidBytes,
  suid,
  suidDate,
  suidBytesDate,
  uuid32bit,
  setUuidDefaultEncoding,
  uuid,
  uuidDecode,
  uuidEncode,
  uuidIsValid,
  uname,
  unameReset,
  qid
};
//# sourceMappingURL=chunk-OKXFHCRW.js.map