import {
  Channel
} from "./chunk-TOCTDWQI.js";
import {
  useDisposeWithUtils
} from "./chunk-734RUVRO.js";

// src/common/msg/channel-resilient.ts
var ResillientChannel = class extends Channel {
  constructor() {
    super(...arguments);
    this.buffer = [];
    this.dispose = useDisposeWithUtils();
  }
  postMessageRaw(data) {
    try {
      if (this.channel?.isConnected) {
        this.channel.postMessage(data);
        return true;
      }
    } catch (err) {
    }
    return false;
  }
  /** Post all buffered messages */
  flushBuffer() {
    while (this.buffer.length) {
      const data = this.buffer.shift();
      if (data && !this.postMessageRaw(data)) {
        this.buffer.unshift(data);
        break;
      }
    }
  }
  /** Reset buffer without force sending */
  emptyBuffer() {
    this.buffer = [];
  }
  /**
   * Set a new channel and flush buffer
   */
  setChannel(channel) {
    void this.dispose();
    this.channel = channel;
    if (channel) {
      this.dispose.add(channel.on("message", (msg) => this.emit("message", msg)));
      if (channel.isConnected)
        this.flushBuffer();
      else
        this.dispose.add(channel.on("connect", () => this.flushBuffer()));
    }
  }
  /** @deprecated use `setChannel(undefined)` */
  deleteChannel() {
    this.setChannel();
  }
  postMessage(data) {
    this.flushBuffer();
    if (!this.postMessageRaw(data))
      this.buffer.push(data);
  }
  get isConnected() {
    return this.channel?.isConnected === true;
  }
};

export {
  ResillientChannel
};
//# sourceMappingURL=chunk-ORVQHQ6Y.js.map