import {
  LoggerHandlerNoop
} from "./chunk-432W2IIS.js";
import {
  browserSupportsColors
} from "./chunk-2DBUDBZF.js";
import {
  browserSelectColorByName
} from "./chunk-I45WP5PM.js";
import {
  getGlobalConsole
} from "./chunk-CV2N52ZM.js";
import {
  parseLogLevel,
  useNamespaceFilter
} from "./chunk-JAGWOLOG.js";
import {
  LogLevelAll,
  LogLevelDebug,
  LogLevelError,
  LogLevelFatal,
  LogLevelInfo,
  LogLevelOff,
  LogLevelWarn
} from "./chunk-YX6CL4KH.js";

// src/browser/log/log-browser-factory.ts
function LoggerBrowserSetupDebugFactory(opt = {}) {
  const filter = opt.filter ?? (typeof localStorage !== "undefined" ? localStorage.zeed ?? localStorage.debug : void 0);
  const styleFont = 'font-family: "JetBrains Mono", Menlo; font-size: 11px;';
  const styleDefault = `${styleFont}`;
  const styleBold = `font-weight: 600; ${styleFont}`;
  const useColors = browserSupportsColors();
  const originalConsole = getGlobalConsole();
  return function LoggerBrowserDebugFactory(name = "", logLevel) {
    let log;
    const matches = useNamespaceFilter(filter);
    const level = parseLogLevel(logLevel ?? LogLevelAll);
    if (matches(name) && level !== LogLevelOff && originalConsole) {
      let defineForLogLevel2 = function(fnLevel, fn) {
        if (level <= fnLevel)
          return fn;
        return () => {
        };
      };
      var defineForLogLevel = defineForLogLevel2;
      const fixedArgs = [];
      if (useColors) {
        const color = browserSelectColorByName(name);
        fixedArgs.push(`%c${name.padEnd(16, " ")}%c 	%s`);
        fixedArgs.push(`color:${color}; ${styleBold}`);
        fixedArgs.push(styleDefault);
      } else {
        fixedArgs.push(`[${name}] 	%s`);
      }
      log = defineForLogLevel2(LogLevelDebug, originalConsole.debug.bind(originalConsole.console, ...fixedArgs));
      log.debug = defineForLogLevel2(LogLevelDebug, originalConsole.debug.bind(originalConsole.console, ...fixedArgs));
      log.info = defineForLogLevel2(LogLevelInfo, originalConsole.info.bind(originalConsole.console, ...fixedArgs));
      log.warn = defineForLogLevel2(LogLevelWarn, originalConsole.warn.bind(originalConsole.console, ...fixedArgs));
      log.error = defineForLogLevel2(LogLevelError, originalConsole.error.bind(originalConsole.console, ...fixedArgs));
      log.fatal = defineForLogLevel2(LogLevelFatal, (...args) => {
        log.error(...args);
        throw new Error(`${args.map(String).join(" ")}`);
      });
      log.assert = defineForLogLevel2(LogLevelFatal, (condition, ...args) => {
        if (condition == null || typeof condition === "number" && Number.isNaN(condition) || !condition)
          log.fatal(...args);
      });
    } else {
      log = LoggerHandlerNoop();
    }
    log.extend = (subName) => {
      return LoggerBrowserDebugFactory(name ? `${name}:${subName}` : subName);
    };
    log.label = name;
    return log;
  };
}

export {
  LoggerBrowserSetupDebugFactory
};
//# sourceMappingURL=chunk-SU6YVBAL.js.map