"use strict"; function _nullishCoalesce(lhs, rhsFn) { if (lhs != null) { return lhs; } else { return rhsFn(); } }







var _chunkBVNSW3CFcjs = require('../../chunk-BVNSW3CF.cjs');


var _chunkMTWPH7QTcjs = require('../../chunk-MTWPH7QT.cjs');
require('../../chunk-XTDX3HZA.cjs');


var _chunk5TCFLJWDcjs = require('../../chunk-5TCFLJWD.cjs');
require('../../chunk-N5KTMDVO.cjs');
require('../../chunk-BOHPEXDM.cjs');
require('../../chunk-6T6PI6XG.cjs');
require('../../chunk-5BF2LEAU.cjs');
require('../../chunk-2BOMVGUQ.cjs');
require('../../chunk-WZOVL24X.cjs');
require('../../chunk-LRK332ID.cjs');
require('../../chunk-UXNOJAXO.cjs');
require('../../chunk-PEU5ZQVB.cjs');
require('../../chunk-J42M6DF3.cjs');
require('../../chunk-ZYPCVNSG.cjs');



var _chunkN43PGEL6cjs = require('../../chunk-N43PGEL6.cjs');
require('../../chunk-W3WUDQIC.cjs');
require('../../chunk-YY4AHBBL.cjs');
require('../../chunk-IMCDDJAJ.cjs');

// src/common/data/object.spec.ts
describe("object.spec", () => {
  it("should map it", async () => {
    const sample = {
      a: 1,
      b: 2
    };
    expect(_chunkBVNSW3CFcjs.objectMap.call(void 0, sample, (k, v) => v + 10)).toMatchInlineSnapshot(`
      Object {
        "a": 11,
        "b": 12,
      }
    `);
    expect(_chunkBVNSW3CFcjs.objectMap.call(void 0, sample, (k, v) => [`${k}_${v}`, k])).toMatchInlineSnapshot(`
        Object {
          "a_1": "a",
          "b_2": "b",
        }
      `);
  });
  it("should merge", async () => {
    const emitter = new (0, _chunkMTWPH7QTcjs.Emitter)();
    const obj = {
      dispose: _chunk5TCFLJWDcjs.useDispose.call(void 0, ),
      f() {
        return 42;
      }
    };
    let x = 1;
    obj.dispose.add(() => x++);
    const m = _chunkBVNSW3CFcjs.objectMergeDisposable.call(void 0, emitter, obj);
    expect(m.f()).toBe(42);
    m.on("a", () => x++);
    void m.emit("a");
    expect(x).toBe(2);
    await m.dispose();
    expect(x).toBe(3);
  });
  it("should omit and pick", () => {
    const o = { a: 1, b: 2, c: 3, d: 4 };
    expect(_chunkBVNSW3CFcjs.objectPick.call(void 0, o, "a", "c")).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "c": 3,
      }
    `);
    expect(_chunkBVNSW3CFcjs.objectOmit.call(void 0, o, "a", "c")).toMatchInlineSnapshot(`
      Object {
        "b": 2,
        "d": 4,
      }
    `);
    expect(_chunkBVNSW3CFcjs.objectInclusivePick.call(void 0, o, "a", "c", "x")).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "c": 3,
        "x": undefined,
      }
    `);
  });
});
describe("objectPlain", () => {
  it("should return the plain object", () => {
    const obj = {
      a: 1,
      b: {
        c: 2,
        d: [3, 4]
      }
    };
    const result = _chunkBVNSW3CFcjs.objectPlain.call(void 0, obj);
    expect(result).toEqual(obj);
  });
  it("should handle bool", async () => {
    const x = _chunkBVNSW3CFcjs.objectPlain.call(void 0, { test: true, fdsf: { fsdafs: false } }, {
      transformer: (obj) => {
        if (_chunkN43PGEL6cjs.isBoolean.call(void 0, obj))
          return +obj;
      }
    });
    expect(x).toMatchInlineSnapshot(`
      Object {
        "fdsf": Object {
          "fsdafs": 0,
        },
        "test": 1,
      }
    `);
  });
  it("should handle circular references", () => {
    const obj = {
      a: 1
    };
    obj.b = obj;
    const result = _chunkBVNSW3CFcjs.objectPlain.call(void 0, obj, { circleValue: "*** CIRCULAR ***" });
    expect(result).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "b": "*** CIRCULAR ***",
      }
    `);
  });
  it("should handle nested objects", () => {
    const obj = {
      a: 1,
      b: {
        c: 2,
        d: {
          e: 3
        }
      }
    };
    const result = _chunkBVNSW3CFcjs.objectPlain.call(void 0, obj);
    expect(result).toEqual(obj);
  });
  it("should handle arrays", () => {
    const obj = {
      a: 1,
      b: [2, 3, 4]
    };
    const result = _chunkBVNSW3CFcjs.objectPlain.call(void 0, obj);
    expect(result).toEqual(obj);
  });
  it("should handle max depth", () => {
    const obj = {
      a: {
        b: {
          c: {
            d: {
              e: 1
            }
          }
        }
      }
    };
    const result = _chunkBVNSW3CFcjs.objectPlain.call(void 0, obj, { maxDepth: 3, maxDepthValue: "*** MAX DEPTH ***" });
    expect(result).toEqual({
      a: {
        b: {
          c: {
            d: "*** MAX DEPTH ***"
          }
        }
      }
    });
  });
  it("should handle removeUndefined", () => {
    const obj = {
      a: 1,
      b: void 0,
      c: [1, void 0]
    };
    const result = _chunkBVNSW3CFcjs.objectPlain.call(void 0, obj, { filter: _chunkN43PGEL6cjs.isNotNull });
    expect(result).toEqual({ a: 1, c: [1] });
  });
  it("should also support crazy stuff", () => {
    function fn() {
      this.y = 1;
    }
    fn.prototype.x = 2;
    fn.z = 6;
    class Klass {
      constructor(name) {
        this.name = _nullishCoalesce(name, () => ( "test"));
      }
    }
    const obj = {
      a: 1,
      b: {
        x: Symbol("x"),
        y: BigInt(123),
        fn,
        bool: true,
        nan: Number.NaN,
        inf: Number.POSITIVE_INFINITY,
        err: new Error("err"),
        set: /* @__PURE__ */ new Set([1, { x: 1 }, 3]),
        rx: /.+?test/gi,
        map: /* @__PURE__ */ new Map([
          ["a", 1],
          ["b", 2],
          [true, "bool"]
        ]),
        date: new Date(Date.UTC(2024, 0, 1, 12)),
        weakMap: /* @__PURE__ */ new WeakMap(),
        uint8: new Uint8Array([1, 2, 3]),
        uint16: new Uint16Array([1, 2, 3]),
        c: 2,
        d: [3, 4, 5],
        Klass,
        newKlass: new Klass("testNewKlass")
      }
    };
    const result = _chunkBVNSW3CFcjs.objectPlain.call(void 0, obj, {
      keepAsIs: (o) => o instanceof Uint8Array,
      errorTrace: false,
      transformer(obj2) {
        if (obj2 instanceof Date)
          return { __timestamp: obj2.getTime() };
        if (_chunkN43PGEL6cjs.isBoolean.call(void 0, obj2))
          return +obj2;
      }
    });
    expect(result).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "b": Object {
          "Klass": Object {
            "__class": "Function",
          },
          "bool": 1,
          "c": 2,
          "d": Array [
            3,
            4,
            5,
          ],
          "date": Object {
            "__timestamp": 1704110400000,
          },
          "err": Object {
            "__class": "Error",
            "cause": undefined,
            "message": "err",
            "name": "Error",
            "stack": undefined,
          },
          "fn": Object {
            "__class": "Function",
            "z": 6,
          },
          "inf": Infinity,
          "map": Object {
            "a": 1,
            "b": 2,
            "true": "bool",
          },
          "nan": NaN,
          "newKlass": Object {
            "__class": "Klass",
            "name": "testNewKlass",
          },
          "rx": Object {
            "__class": "RegExp",
            "source": "/.+?test/gi",
          },
          "set": Array [
            1,
            Object {
              "x": 1,
            },
            3,
          ],
          "uint16": Array [
            1,
            2,
            3,
          ],
          "uint8": Uint8Array [
            1,
            2,
            3,
          ],
          "weakMap": Object {
            "__class": "WeakMap",
          },
          "x": "Symbol(x)",
          "y": 123n,
        },
      }
    `);
    const result2 = _chunkBVNSW3CFcjs.objectPlain.call(void 0, obj);
    expect(_chunkBVNSW3CFcjs.objectPlain.call(void 0, result2)).toEqual(result2);
  });
});
describe("objectFilter", () => {
  it("should return an empty object for non-object inputs", () => {
    expect(_chunkBVNSW3CFcjs.objectFilter.call(void 0, null, () => true)).toEqual({});
    expect(_chunkBVNSW3CFcjs.objectFilter.call(void 0, void 0, () => true)).toEqual({});
    expect(_chunkBVNSW3CFcjs.objectFilter.call(void 0, 42, () => true)).toEqual({});
    expect(_chunkBVNSW3CFcjs.objectFilter.call(void 0, "string", () => true)).toEqual({});
  });
  it("should return an empty object if the object has no properties that match the filter", () => {
    const input = { a: 1, b: 2, c: 3 };
    const result = _chunkBVNSW3CFcjs.objectFilter.call(void 0, input, (key, value) => value > 5);
    expect(result).toEqual({});
  });
  it("should return an object with properties that match the filter", () => {
    const input = { a: 1, b: 2, c: 3, d: 4 };
    const result = _chunkBVNSW3CFcjs.objectFilter.call(void 0, input, (key, value) => value % 2 === 0);
    expect(result).toEqual({ b: 2, d: 4 });
  });
  it("should return an object with properties that match the filter based on keys", () => {
    const input = { a: 1, b: 2, c: 3, d: 4 };
    const result = _chunkBVNSW3CFcjs.objectFilter.call(void 0, input, (key) => key === "a" || key === "c");
    expect(result).toEqual({ a: 1, c: 3 });
  });
  it("should handle an empty object", () => {
    const input = {};
    const result = _chunkBVNSW3CFcjs.objectFilter.call(void 0, input, () => true);
    expect(result).toEqual({});
  });
  it("should return a partial object when some properties match the filter", () => {
    const input = { a: 1, b: 2, c: 3, d: 4 };
    const result = _chunkBVNSW3CFcjs.objectFilter.call(void 0, input, (key, value) => key !== "b");
    expect(result).toEqual({ a: 1, c: 3, d: 4 });
  });
});
//# sourceMappingURL=object.spec.cjs.map