import {
  useDisposeWithUtils,
  useEventListener,
  useTimeout
} from "../chunk-734RUVRO.js";
import {
  polyfillUsing
} from "../chunk-3K65A2PU.js";
import "../chunk-L324TYGN.js";
import "../chunk-K7Z2KDW3.js";
import "../chunk-GY34N3KU.js";
import "../chunk-QUKKMPRF.js";
import "../chunk-QLW2QJ6C.js";
import "../chunk-LUGJYROQ.js";
import "../chunk-4P5GCQLI.js";
import "../chunk-CV2N52ZM.js";
import "../chunk-JAGWOLOG.js";
import "../chunk-YX6CL4KH.js";
import "../chunk-CFICINSP.js";
import "../chunk-MSASB4XB.js";
import "../chunk-UOAPXGA4.js";
import "../chunk-EAYWSLQT.js";
import {
  __callDispose,
  __using
} from "../chunk-I7BWSAN6.js";

// src/common/dispose-utils.spec.ts
import { vi as jest } from "vitest";
describe("useTimeout", () => {
  it("should call the provided function after the specified timeout", () => {
    jest.useFakeTimers();
    const mockFn = jest.fn();
    const timeout = 1e3;
    useTimeout(mockFn, timeout);
    expect(mockFn).not.toBeCalled();
    jest.advanceTimersByTime(timeout);
    expect(mockFn).toBeCalled();
  });
  it("should cancel the timeout when the disposer function is called", () => {
    jest.useFakeTimers();
    const mockFn = jest.fn();
    const timeout = 1e3;
    const disposer = useTimeout(mockFn, timeout);
    expect(mockFn).not.toBeCalled();
    disposer();
    jest.advanceTimersByTime(timeout);
    expect(mockFn).not.toBeCalled();
  });
  it('should add event listener using "on" method if available', () => {
    const emitter = {
      on: jest.fn(),
      off: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const disposer = useEventListener(emitter, eventName, fn, ...args);
    expect(emitter.on).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.off).not.toBeCalled();
    disposer();
    expect(emitter.off).toBeCalledWith(eventName, fn, ...args);
  });
  it('should add event listener using "on" method if available using using', () => {
    const emitter = {
      on: jest.fn(),
      off: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    polyfillUsing();
    function helper() {
      var _stack = [];
      try {
        const _ = __using(_stack, useEventListener(emitter, eventName, fn, ...args));
        expect(emitter.on).toBeCalledWith(eventName, fn, ...args);
        expect(emitter.off).not.toBeCalled();
      } catch (_2) {
        var _error = _2, _hasError = true;
      } finally {
        __callDispose(_stack, _error, _hasError);
      }
    }
    helper();
    expect(emitter.off).toBeCalledWith(eventName, fn, ...args);
  });
  it('should add event listener using "addEventListener" method if "on" method is not available', () => {
    const emitter = {
      addEventListener: jest.fn(),
      removeEventListener: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const disposer = useEventListener(emitter, eventName, fn, ...args);
    expect(emitter.addEventListener).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.removeEventListener).not.toBeCalled();
    disposer();
    expect(emitter.removeEventListener).toBeCalledWith(eventName, fn, ...args);
  });
  it("should return an empty disposer function if emitter is null", () => {
    const emitter = null;
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const disposer = useEventListener(emitter, eventName, fn, ...args);
    expect(disposer).toEqual(expect.any(Function));
    disposer();
  });
  it("should add timeout disposer to the dispose object", () => {
    jest.useFakeTimers();
    const mockFn = jest.fn();
    const timeout = 1e3;
    const dispose = useDisposeWithUtils();
    dispose.timeout(mockFn, timeout);
    expect(mockFn).not.toBeCalled();
    jest.advanceTimersByTime(timeout);
    expect(mockFn).toBeCalled();
  });
  it("should add interval disposer to the dispose object", () => {
    jest.useFakeTimers();
    const mockFn = jest.fn();
    const interval = 1e3;
    const dispose = useDisposeWithUtils();
    dispose.interval(mockFn, interval);
    expect(mockFn).not.toBeCalled();
    jest.advanceTimersByTime(interval);
    expect(mockFn).toBeCalled();
  });
  it('should add event listener disposer to the dispose object using "on" method', async () => {
    const emitter = {
      on: jest.fn(),
      off: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const dispose = useDisposeWithUtils();
    dispose.on(emitter, eventName, fn, ...args);
    expect(emitter.on).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.off).not.toBeCalled();
    await dispose.dispose();
    expect(emitter.off).toBeCalledWith(eventName, fn, ...args);
  });
  it('should add event listener disposer to the dispose object using "addEventListener" method', async () => {
    const emitter = {
      addEventListener: jest.fn(),
      removeEventListener: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const dispose = useDisposeWithUtils();
    dispose.on(emitter, eventName, fn, ...args);
    expect(emitter.addEventListener).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.removeEventListener).not.toBeCalled();
    await dispose.dispose();
    expect(emitter.removeEventListener).toBeCalledWith(eventName, fn, ...args);
  });
  it("should return an empty disposer function if emitter is null 2", () => {
    const emitter = null;
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const dispose = useDisposeWithUtils();
    const disposer = dispose.on(emitter, eventName, fn, ...args);
    expect(disposer).toEqual(expect.any(Function));
    disposer();
  });
});
//# sourceMappingURL=dispose-utils.spec.js.map