import {
  Progress
} from "../../chunk-TOSLGV7Y.js";
import "../../chunk-OPA3P4S3.js";
import "../../chunk-7QYVSWCZ.js";
import "../../chunk-OKXFHCRW.js";
import "../../chunk-LRNHXH3A.js";
import "../../chunk-3K65A2PU.js";
import "../../chunk-L324TYGN.js";
import "../../chunk-K7Z2KDW3.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-QUKKMPRF.js";
import "../../chunk-QLW2QJ6C.js";
import "../../chunk-LUGJYROQ.js";
import "../../chunk-4P5GCQLI.js";
import "../../chunk-N33MGVUS.js";
import "../../chunk-4LNR3HBM.js";
import "../../chunk-NDJRHQ42.js";
import "../../chunk-NNCJ3QL5.js";
import "../../chunk-CV2N52ZM.js";
import "../../chunk-JAGWOLOG.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-MSASB4XB.js";
import "../../chunk-UOAPXGA4.js";
import "../../chunk-EAYWSLQT.js";
import "../../chunk-I7BWSAN6.js";

// src/common/exec/progress.spec.ts
describe("progress.spec", () => {
  it("should track progress", async () => {
    const p = new Progress({
      name: "root",
      totalUnits: 10
    });
    expect(p.getFraction()).toBe(0);
    p.incCompletedUnits();
    expect(p.getTotalUnits()).toBe(10);
    expect(p.getCompletedUnits()).toBe(1);
    expect(p.getFraction()).toBe(0.1);
    const pp = new Progress();
    p.addChild(pp);
    expect(p.getChildrenCount()).toBe(1);
    expect(p.getFraction()).toBe(0.1);
    pp.setTotalUnits(10);
    expect(p.getFraction()).toBe(0.05);
    pp.incCompletedUnits(5);
    expect(p.getTotalUnits()).toBe(20);
    expect(p.getCompletedUnits()).toBe(6);
    expect(p.getFraction()).toBe(0.3);
    expect(p.toString()).toMatchInlineSnapshot(`
      "root: 1 of 10 units, 30 %, cancel=false
        progress-0: 5 of 10 units, 50 %, cancel=false"
    `);
    expect(pp.isFinished()).toBe(false);
    expect(p.getChildrenCount()).toBe(1);
    await pp.dispose();
    expect(p.getChildrenCount()).toBe(0);
    expect(pp.isFinished()).toBe(true);
    expect(p.getTotalUnits()).toBe(10);
    expect(p.getCompletedUnits()).toBe(1);
    expect(p.getFraction()).toBe(0.1);
    expect(p.isFinished()).toBe(false);
    p.setCompletetedUnits(10);
    expect(p.getFraction()).toBe(1);
    expect(p.isFinished()).toBe(true);
  });
  it("should cancel and auto reset", async () => {
    const p = new Progress({
      totalUnits: 10
    });
    expect(p.isCancelled()).toBe(false);
    await p.cancel();
    expect(p.isCancelled()).toBe(true);
    p.incCompletedUnits(10);
    expect(p.isFinished()).toBe(true);
    expect(p.isCancelled()).toBe(false);
  });
});
//# sourceMappingURL=progress.spec.js.map