import {
  SerialQueue
} from "../../chunk-UC4IXJII.js";
import "../../chunk-OPA3P4S3.js";
import "../../chunk-7QYVSWCZ.js";
import "../../chunk-OKXFHCRW.js";
import "../../chunk-LRNHXH3A.js";
import {
  sleep
} from "../../chunk-L324TYGN.js";
import "../../chunk-QLW2QJ6C.js";
import "../../chunk-LUGJYROQ.js";
import "../../chunk-4P5GCQLI.js";
import "../../chunk-N33MGVUS.js";
import "../../chunk-4LNR3HBM.js";
import "../../chunk-NDJRHQ42.js";
import "../../chunk-NNCJ3QL5.js";
import "../../chunk-CV2N52ZM.js";
import "../../chunk-JAGWOLOG.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-MSASB4XB.js";
import "../../chunk-UOAPXGA4.js";
import "../../chunk-EAYWSLQT.js";
import "../../chunk-I7BWSAN6.js";

// src/common/exec/queue.spec.ts
describe("queue", () => {
  it("should execute in strict order", async () => {
    expect.assertions(1);
    const list = [];
    const queue = new SerialQueue();
    void queue.enqueue(async () => {
      await sleep(100);
      list.push("a");
    });
    void queue.enqueue(async () => {
      await sleep(200);
      list.push("b");
    });
    void queue.enqueue(async () => {
      await sleep(1);
      list.push("c");
    });
    await queue.wait();
    expect(list).toEqual(["a", "b", "c"]);
  });
  it("should execute in random order", async () => {
    expect.assertions(1);
    const list = [];
    void (async () => {
      await sleep(100);
      list.push("a");
    })();
    void (async () => {
      await sleep(200);
      list.push("b");
    })();
    void (async () => {
      await sleep(1);
      list.push("c");
    })();
    await sleep(500);
    expect(list).toEqual(["c", "a", "b"]);
  });
  it("should return value", async () => {
    expect.assertions(2);
    const list = [];
    const queue = new SerialQueue();
    void queue.enqueue(async () => {
      await sleep(100);
      list.push("a");
    });
    const r = await queue.enqueue(async () => {
      await sleep(200);
      list.push("b");
      return 123;
    });
    expect(r).toEqual(123);
    expect(list).toEqual(["a", "b"]);
    await queue.wait();
  });
  it("should pause", async () => {
    expect.assertions(3);
    const list = [];
    const queue = new SerialQueue();
    const events = [];
    queue.onAny((...args) => events.push(args));
    void queue.enqueue(async () => {
      await sleep(100);
      list.push("a");
    });
    void queue.enqueue(async () => {
      await sleep(200);
      list.push("b");
    });
    void queue.enqueue(async () => {
      await sleep(1);
      list.push("c");
    });
    await queue.pause();
    expect(list).toEqual(["a"]);
    queue.resume();
    await queue.wait();
    expect(list).toEqual(["a", "b", "c"]);
    expect(events).toMatchInlineSnapshot(`
      Array [
        Array [
          "didUpdate",
          1,
          0,
        ],
        Array [
          "didStart",
          1,
        ],
        Array [
          "didUpdate",
          2,
          0,
        ],
        Array [
          "didUpdate",
          3,
          0,
        ],
        Array [
          "didUpdate",
          3,
          1,
        ],
        Array [
          "didUpdate",
          3,
          2,
        ],
        Array [
          "didUpdate",
          3,
          3,
        ],
        Array [
          "didFinish",
        ],
      ]
    `);
  });
  it("should cancel the rest", async () => {
    expect.assertions(3);
    const list = [];
    const queue = new SerialQueue();
    const events = [];
    queue.onAny((...args) => events.push(args));
    await queue.pause();
    void queue.enqueue(async () => {
      await sleep(100);
      list.push("a");
    });
    void queue.enqueue(async () => {
      await sleep(200);
      list.push("b");
    });
    void queue.enqueue(async () => {
      await sleep(1);
      list.push("c");
    }).then((r) => {
      expect(r).toBe(void 0);
    });
    await queue.cancelAll();
    queue.resume();
    await queue.wait();
    expect(list).toEqual([]);
    expect(events).toMatchInlineSnapshot(`
      Array [
        Array [
          "didUpdate",
          1,
          0,
        ],
        Array [
          "didUpdate",
          2,
          0,
        ],
        Array [
          "didUpdate",
          3,
          0,
        ],
        Array [
          "didCancel",
        ],
        Array [
          "didFinish",
        ],
      ]
    `);
  });
});
//# sourceMappingURL=queue.spec.js.map