import {
  useRPC,
  useRPCHub
} from "../../chunk-44XNTK3T.js";
import {
  createLocalChannelPair
} from "../../chunk-LOKSBIQW.js";
import "../../chunk-TOCTDWQI.js";
import {
  useStringHashPool
} from "../../chunk-2H4XRKWS.js";
import "../../chunk-NSJKG6AJ.js";
import {
  decodeJson,
  encodeJson
} from "../../chunk-WTRJ3FHO.js";
import "../../chunk-CEWTZYJD.js";
import "../../chunk-F64SQULL.js";
import "../../chunk-RNL46FQ3.js";
import "../../chunk-MWUFUBY5.js";
import "../../chunk-GKKLBSFA.js";
import "../../chunk-OPA3P4S3.js";
import "../../chunk-7QYVSWCZ.js";
import "../../chunk-OKXFHCRW.js";
import "../../chunk-LRNHXH3A.js";
import "../../chunk-3K65A2PU.js";
import {
  sleep
} from "../../chunk-L324TYGN.js";
import "../../chunk-K7Z2KDW3.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-QUKKMPRF.js";
import "../../chunk-GAB5OQ4U.js";
import "../../chunk-QLW2QJ6C.js";
import "../../chunk-LUGJYROQ.js";
import "../../chunk-4P5GCQLI.js";
import "../../chunk-N33MGVUS.js";
import "../../chunk-4LNR3HBM.js";
import "../../chunk-NDJRHQ42.js";
import "../../chunk-NNCJ3QL5.js";
import "../../chunk-CV2N52ZM.js";
import "../../chunk-JAGWOLOG.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-MSASB4XB.js";
import {
  cloneObject
} from "../../chunk-UOAPXGA4.js";
import "../../chunk-EAYWSLQT.js";
import "../../chunk-I7BWSAN6.js";

// src/common/msg/rpc.spec.ts
var bobCount = 0;
var Bob = {
  hi(name) {
    return `Hi ${name}, I am Bob`;
  },
  bump() {
    bobCount += 1;
  },
  getCount() {
    return bobCount;
  }
};
var Alice = {
  hello(name) {
    return `Hello ${name}, my name is Alice`;
  }
};
describe("rpc async", () => {
  beforeEach(() => {
    bobCount = 0;
  });
  it("basic", async () => {
    const log = [];
    const [c1, c2] = createLocalChannelPair();
    const serialize = (data) => {
      log.push(cloneObject(data));
      return encodeJson(data);
    };
    const deserialize = (data) => decodeJson(data);
    const bob = useRPC(Bob, {
      post: (data) => c1.postMessage(data),
      on: (data) => c1.on("message", (e) => data(e.data)),
      serialize,
      deserialize,
      stringHashPool: useStringHashPool()
    });
    const alice = useRPC(Alice, {
      // mark bob's `bump` as an event without response
      eventNames: ["bump"],
      post: (data) => c2.postMessage(data),
      on: (data) => c2.on("message", (e) => data(e.data)),
      serialize,
      deserialize,
      stringHashPool: useStringHashPool()
    });
    expect(await bob.hello("Bob")).toEqual("Hello Bob, my name is Alice");
    expect(await alice.hi("Alice")).toEqual("Hi Alice, I am Bob");
    expect(void alice.bump()).toBeUndefined();
    expect(Bob.getCount()).toBe(0);
    await new Promise((resolve) => setTimeout(resolve, 100));
    expect(Bob.getCount()).toBe(1);
    c1.close();
    c2.close();
    expect(log).toMatchInlineSnapshot(`
      Array [
        Array [
          1,
          1,
          1335831723,
          "Bob",
        ],
        Array [
          3,
          1,
          "Hello Bob, my name is Alice",
        ],
        Array [
          1,
          2,
          1748694682,
          "Alice",
        ],
        Array [
          3,
          2,
          "Hi Alice, I am Bob",
        ],
        Array [
          2,
          1648103349,
        ],
      ]
    `);
  });
  it("hub", async () => {
    const [c1, c2] = createLocalChannelPair();
    const serialize = (data) => encodeJson(data);
    const deserialize = (data) => decodeJson(data);
    const bobHub = useRPCHub({
      post: (data) => c1.postMessage(data),
      on: (data) => c1.on("message", (e) => data(e.data)),
      serialize,
      deserialize,
      stringHashPool: useStringHashPool()
    });
    const bob = bobHub(Bob);
    const alice = useRPC(Alice, {
      // mark bob's `bump` as an event without response
      eventNames: ["bump"],
      post: (data) => c2.postMessage(data),
      on: (data) => c2.on("message", (e) => data(e.data)),
      serialize,
      deserialize,
      stringHashPool: useStringHashPool()
    });
    expect(await bob.hello("Bob")).toEqual("Hello Bob, my name is Alice");
    expect(await alice.hi("Alice")).toEqual("Hi Alice, I am Bob");
    expect(void alice.bump()).toBeUndefined();
    expect(Bob.getCount()).toBe(0);
    await new Promise((resolve) => setTimeout(resolve, 100));
    expect(Bob.getCount()).toBe(1);
    c1.close();
    c2.close();
  });
  it("timeout async", async (done) => {
    const [f1, f2] = createLocalChannelPair();
    const rpc1 = useRPC({
      async echo(v, s = 5) {
        await sleep(s);
        return `${v}_1`;
      }
    }, {
      post: (data) => {
        f1.postMessage(data);
      },
      on: (data) => f1.on("message", (msg) => {
        void data(msg.data);
      }),
      timeout: 10
    });
    const rpc2 = useRPC({
      async echo(v, s = 5) {
        await sleep(s);
        return `${v}_2`;
      }
    }, {
      post: (data) => {
        f2.postMessage(data);
      },
      on: (data) => f2.on("message", (msg) => {
        void data(msg.data);
      }),
      timeout: 10
    });
    const r = await rpc1.echo("abc");
    expect(r).toMatchInlineSnapshot(`"abc_2"`);
    try {
      const r2 = await rpc1.echo("abc", 50);
      expect(false).toBe(true);
    } catch (err) {
      expect(err).toMatchInlineSnapshot(`[Error: rpc timeout on calling "echo"]`);
    }
  });
  it("async", async (done) => {
    function echo(n) {
      return n;
    }
    async function echoAsync(n) {
      return n;
    }
    expect(await echo(1)).toBe(1);
    expect(await echoAsync(2)).toBe(2);
  });
});
//# sourceMappingURL=rpc.spec.js.map