import {
  parseSchemaEnv,
  stringFromSchemaEnv
} from "../../chunk-EVV5XSMX.js";
import "../../chunk-HIX6EHLQ.js";
import {
  boolean,
  number,
  object,
  string
} from "../../chunk-QY5DHPIN.js";
import "../../chunk-KKN5DQUJ.js";
import "../../chunk-XOAKJFNZ.js";
import "../../chunk-PIP5E7GF.js";
import "../../chunk-GAB5OQ4U.js";
import "../../chunk-QLW2QJ6C.js";
import "../../chunk-LUGJYROQ.js";
import "../../chunk-4P5GCQLI.js";
import "../../chunk-CV2N52ZM.js";
import "../../chunk-JAGWOLOG.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-MSASB4XB.js";
import "../../chunk-UOAPXGA4.js";
import "../../chunk-EAYWSLQT.js";
import "../../chunk-I7BWSAN6.js";

// src/common/schema/env.spec.ts
describe("env.spec", () => {
  it("parse env", async () => {
    const schema = object({
      ServiceName: string().default("generic"),
      servicePort: number().default(80),
      ServiceFlag: boolean().default(true)
    });
    const r = parseSchemaEnv(schema, {
      SERVICE_NAME: "SomeThing",
      SERVICE_PORT: " 8888 ",
      SERVICE_FLAG: "illegalValueTriggerDefault"
    });
    expect(r).toMatchInlineSnapshot(`
      Object {
        "ServiceFlag": true,
        "ServiceName": "SomeThing",
        "servicePort": 8888,
      }
    `);
  });
  it("parse prefix", async () => {
    const schema = object({
      ServiceName: string().default("generic"),
      servicePort: number().default(80),
      ServiceFlag: boolean().default(true)
    });
    const r = parseSchemaEnv(schema, {
      SERVICE_NAME: "SomeThing",
      SERVICE_PORT: " 8888 ",
      APP_SERVICE_PORT: " 9999",
      SERVICE_FLAG: "illegalValueTriggerDefault"
    }, "APP_");
    expect(r).toMatchInlineSnapshot(`
      Object {
        "ServiceFlag": true,
        "ServiceName": "generic",
        "servicePort": 9999,
      }
    `);
    expect(stringFromSchemaEnv(schema, "APP_", true)).toMatchInlineSnapshot(`
      "# APP_SERVICE_NAME=generic
      # APP_SERVICE_PORT=80
      # APP_SERVICE_FLAG=true"
    `);
  });
});
//# sourceMappingURL=env.spec.js.map