interface TypeProps {
}
interface Type<T = unknown> {
    _default?: T;
    _optional?: boolean;
    _props?: TypeProps;
    _object?: T;
    readonly type: string;
    readonly _check: (obj: any) => boolean;
    optional: () => Type<T | undefined>;
    default: (value: any) => Type<T | undefined>;
    parse: (obj: any) => T;
    map: (obj: any, fn: (this: Type<T>, obj: any, schema: Type<T>) => any) => any;
    props: (props: TypeProps) => Type<T>;
}
declare abstract class TypeClass<T = unknown> implements Type<T> {
    readonly type: string;
    readonly _check: (obj: any) => boolean;
    constructor(name: string, check?: (obj: any) => boolean);
    _object?: T;
    _optional?: boolean;
    optional(): TypeClass<T | undefined>;
    _default?: T;
    default(value: any): TypeClass<T | undefined>;
    parse(obj: any): T;
    map(obj: any, fn: (this: Type<T>, obj: any, schema: Type<T>) => any): any;
    _props?: TypeProps;
    props(props: TypeProps): this;
}
type Infer<T> = T extends Type<infer TT> ? TT : never;
declare class TypeStringClass<T extends string> extends TypeClass<T> {
    pattern(rx: RegExp): this;
}
declare function string(): TypeStringClass<string>;
declare function number(): Type<number>;
declare const float: typeof number;
declare function int(): Type<number>;
declare function boolean(): Type<boolean>;
type ObjectFixOptional<T> = {
    [K in keyof T as undefined extends T[K] ? K : never]?: T[K] & {};
} & {
    [K in keyof T as undefined extends T[K] ? never : K]: T[K] & {};
};
type ObjectPretty<V> = Extract<{
    [K in keyof V]: V[K];
}, unknown>;
type InferObject<T> = ObjectPretty<ObjectFixOptional<{
    [K in keyof T]: Infer<T[K]>;
}>>;
declare class TypeObjectClass<T, O = InferObject<T>> extends TypeClass<O> {
    constructor(obj: T);
    parse(obj: any): any;
    map(obj: any, fn: (this: Type<O>, obj: any, schema: Type<O>) => any): any;
}
declare function object<T>(tobj: T): Type<InferObject<T>>;
type TransformToUnion<T extends (Type<any>)[]> = T extends Array<infer U> ? Infer<U> : never;
declare function union<T extends (Type<any>)[]>(options: T): Type<TransformToUnion<T>>;
type Literal = string | number | bigint | boolean;
declare function literal<T extends Literal>(value: T): Type<T>;
declare function stringLiterals<const T extends readonly string[], O = T[number]>(value: T): Type<O>;
type TupleOutput<T extends Type[]> = {
    [K in keyof T]: T[K] extends Type<infer U> ? U : never;
};
type ArrayOutput<Head extends Type[], Rest extends Type | undefined> = [
    ...TupleOutput<Head>,
    ...(Rest extends Type ? Infer<Rest>[] : [])
];
type ArrayType<Head extends Type[] = Type[], Rest extends Type | undefined = Type | undefined> = Type<ArrayOutput<Head, Rest>>;
declare function tuple<T extends [] | [Type, ...Type[]]>(items: T): ArrayType<T, undefined>;
declare function func<Args extends [Type<unknown>, ...Type<any>[]] | [], Ret = Type, T = (...args: TupleOutput<Args>) => Infer<Ret>>(args: Args, ret: Ret): Type<T>;

export { type Infer, type InferObject, type Type, TypeClass, TypeObjectClass, type TypeProps, boolean, float, func, int, literal, number, object, string, stringLiterals, tuple, union };
