import "../chunk-EW6FHLFK.js";
import "../chunk-UC4IXJII.js";
import "../chunk-2VA3UGW7.js";
import "../chunk-5OVSRAPG.js";
import "../chunk-X7FSUPTB.js";
import "../chunk-TOSLGV7Y.js";
import "../chunk-OPA3P4S3.js";
import "../chunk-7QYVSWCZ.js";
import "../chunk-OKXFHCRW.js";
import "../chunk-LRNHXH3A.js";
import "../chunk-3K65A2PU.js";
import {
  sleep
} from "../chunk-L324TYGN.js";
import "../chunk-K7Z2KDW3.js";
import "../chunk-GY34N3KU.js";
import "../chunk-QUKKMPRF.js";
import "../chunk-QLW2QJ6C.js";
import "../chunk-LUGJYROQ.js";
import "../chunk-4P5GCQLI.js";
import "../chunk-N33MGVUS.js";
import "../chunk-4LNR3HBM.js";
import "../chunk-NDJRHQ42.js";
import {
  dateFromSeconds,
  datetimeToLocal,
  datetimeToUTC,
  duration,
  formatMilliseconds,
  getPerformanceTimestamp,
  getTimestamp,
  getTimestampInSeconds,
  parseDate,
  timestampMillisecondsToSeconds,
  timestampSecondsToMilliseconds
} from "../chunk-NNCJ3QL5.js";
import "../chunk-CV2N52ZM.js";
import "../chunk-JAGWOLOG.js";
import "../chunk-YX6CL4KH.js";
import "../chunk-CFICINSP.js";
import "../chunk-MSASB4XB.js";
import "../chunk-UOAPXGA4.js";
import "../chunk-EAYWSLQT.js";
import "../chunk-I7BWSAN6.js";

// src/common/time.spec.ts
describe("time.spec", () => {
  it("should measure", async () => {
    const getDuration = duration();
    await sleep(50);
    const elapsed = getDuration();
    expect(/\d+.\d\d ms/.test(elapsed)).toBe(true);
  });
  it("should parse valid date strings", () => {
    const date1 = parseDate("2022-01-01");
    const date2 = parseDate("2022-01-01T12:00:00");
    expect(date1).toEqual(new Date(2022, 0, 1, 12, 0));
    expect(date2).toEqual(/* @__PURE__ */ new Date("2022-01-01T12:00:00"));
  });
  it("should return undefined for invalid date strings", () => {
    const date = parseDate("invalid-date");
    expect(date).toBeUndefined();
  });
  it("should return the input date if it is already a Date object", () => {
    const inputDate = /* @__PURE__ */ new Date();
    const date = parseDate(inputDate);
    expect(date).toBe(inputDate);
  });
  it("should convert dates", () => {
    const dateLocal = /* @__PURE__ */ new Date("2022-01-01T12:00:00");
    expect(datetimeToLocal(datetimeToUTC(dateLocal))).toEqual(dateLocal);
  });
  it("should return the current timestamp in milliseconds", () => {
    const timestamp = getTimestamp();
    expect(typeof timestamp).toBe("number");
    expect(timestamp).toBeCloseTo(Date.now(), -2);
  });
  it("should return the current timestamp in seconds", () => {
    const timestampInSeconds = getTimestampInSeconds();
    expect(typeof timestampInSeconds).toBe("number");
    expect(timestampInSeconds).toBeCloseTo(Math.floor(Date.now() / 1e3), -2);
  });
  it("should convert seconds to a Date object", () => {
    const seconds = 1640995200;
    const date = dateFromSeconds(seconds);
    expect(date).toEqual(/* @__PURE__ */ new Date("2022-01-01T00:00:00.000Z"));
  });
  it("should format milliseconds", () => {
    const milliseconds = 1234;
    const formatted = formatMilliseconds(milliseconds);
    expect(formatted).toBe("1.2 s");
  });
  it("should return the current timestamp using performance.now if available", () => {
    const timestamp = getPerformanceTimestamp();
    expect(typeof timestamp).toBe("number");
    expect(timestamp).toBeCloseTo(typeof performance !== "undefined" ? performance.now() : Date.now(), -2);
  });
  it("should measure the duration of a function", async () => {
    const getDuration = duration();
    await sleep(50);
    const elapsed = getDuration();
    expect(/\d+.\d\d ms/.test(elapsed)).toBe(true);
  });
  it("should convert a date to UTC time", () => {
    const date = /* @__PURE__ */ new Date("2022-01-01T12:00:00");
    const utcDate = datetimeToUTC(date);
    expect(utcDate).toEqual(/* @__PURE__ */ new Date("2022-01-01T12:00:00Z"));
  });
  it("should convert milliseconds to seconds", () => {
    const ts = 16094592e5;
    const result = timestampMillisecondsToSeconds(ts);
    expect(result).toBe(1609459200);
  });
  it("should log a warning if the timestamp is already in seconds", () => {
    const ts = 1609459200;
    const result = timestampMillisecondsToSeconds(ts);
    expect(result).toBe(1609459200);
  });
  it("should convert seconds to milliseconds", () => {
    const ts = 1609459200;
    const result = timestampSecondsToMilliseconds(ts);
    expect(result).toBe(16094592e5);
  });
  it("should log a warning if the timestamp is already in milliseconds", () => {
    const ts = 16094592e5;
    const result = timestampMillisecondsToSeconds(ts);
    expect(result).toBe(1609459200);
  });
});
//# sourceMappingURL=time.spec.js.map