"use strict";



var _chunkSFTW3AI4cjs = require('../chunk-SFTW3AI4.cjs');
require('../chunk-UGZ2626O.cjs');
require('../chunk-TZOPYZVR.cjs');
require('../chunk-SK66U3XO.cjs');
require('../chunk-T5NX3H2C.cjs');
require('../chunk-N43PGEL6.cjs');
require('../chunk-W3WUDQIC.cjs');
require('../chunk-YY4AHBBL.cjs');
require('../chunk-IMCDDJAJ.cjs');

// src/node/files-async.spec.ts
describe("getStatAsync", () => {
  it("should return the stat object for a valid path", async () => {
    const path = __filename;
    const statObject = await _chunkSFTW3AI4cjs.getStatAsync.call(void 0, path);
    expect(statObject).toBeDefined();
    expect(statObject.isFile()).toBe(true);
  });
  it("should return undefined for an invalid path", async () => {
    const path = "/invalid/path";
    const statObject = await _chunkSFTW3AI4cjs.getStatAsync.call(void 0, path);
    expect(statObject).toBeUndefined();
  });
  it("should return the fingerprint for a valid path", async () => {
    const path = __filename;
    const fingerprint = await _chunkSFTW3AI4cjs.getFingerprintAsync.call(void 0, path);
    expect(fingerprint).toBeDefined();
    expect(typeof fingerprint).toBe("string");
  });
  it("should return undefined for an invalid path 2", async () => {
    const path = "/invalid/path";
    const fingerprint = await _chunkSFTW3AI4cjs.getFingerprintAsync.call(void 0, path);
    expect(fingerprint).toBeUndefined();
  });
  it("should return an array of file paths", async () => {
    const paths = await _chunkSFTW3AI4cjs.filesAsync.call(void 0, { basePath: __dirname });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBeGreaterThan(0);
    expect(typeof paths[0]).toBe("string");
  });
  it("should return an array of file paths matching the pattern", async () => {
    const pattern = "*.ts";
    const paths = await _chunkSFTW3AI4cjs.filesAsync.call(void 0, { basePath: __dirname, pattern });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBeGreaterThan(0);
    expect(typeof paths[0]).toBe("string");
    expect(paths.every((path) => path.endsWith(".ts"))).toBe(true);
  });
  it("should return an empty array if no files match the pattern", async () => {
    const pattern = "*.docx";
    const paths = await _chunkSFTW3AI4cjs.filesAsync.call(void 0, { basePath: __dirname, pattern });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBe(0);
  });
  it("should return an array of file paths filtered by the custom filter function", async () => {
    const filter = (name) => name.includes("spec");
    const paths = await _chunkSFTW3AI4cjs.filesAsync.call(void 0, { basePath: __dirname, filter });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBeGreaterThan(0);
    expect(typeof paths[0]).toBe("string");
    expect(paths.every((path) => path.includes("spec"))).toBe(true);
  });
  it("should return an empty array if no files pass the custom filter function", async () => {
    const filter = (name) => name.includes("xyz");
    const paths = await _chunkSFTW3AI4cjs.filesAsync.call(void 0, { basePath: __dirname, filter });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBe(0);
  });
  it("should ignore hidden files by default", async () => {
    const paths = await _chunkSFTW3AI4cjs.filesAsync.call(void 0, { basePath: __dirname });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.every((path) => !path.includes("/."))).toBe(true);
  });
});
//# sourceMappingURL=files-async.spec.cjs.map